
popstar
=======

Integrated light synthetic spectra of a simple stellar population.

Authors
-------

- **David Nidever** (Montana State University)
  
Installation
------------

You can also pip install directly from GitHub::

    pip install git+https://github.com/dnidever/popstar

